
/*-----------------------------------------------------------------------------------------------------------------------------------
| -----------------------------------------------------------------------------------------------------------------------------------
|
|	Card : Object
|
|	Instances of this class provide low-level functionality for card games.  Cards can have a
|	suit, a value, and an orientation.  These values can be initialized, modified and determined
|	by clients of the class.  Cards also know how to render themselves on screen.
|
| -----------------------------------------------------------------------------------------------------------------------------------
\----------------------------------------------------------------------------------------------------------------------------------*/

#import <appkit/appkit.h>

typedef enum _CardValue
{
	CS_LOWVALUE = 0,
	CS_ACE = 0,
	CS_TWO,
	CS_THREE,
	CS_FOUR,
	CS_FIVE,
	CS_SIX,
	CS_SEVEN,
	CS_EIGHT,
	CS_NINE,
	CS_TEN,
	CS_JACK,
	CS_QUEEN,
	CS_KING,
	CS_HIGHVALUE = CS_KING
} CardValue ;

typedef enum _CardSuit
{
	CS_LOWSUIT = 0,
	CS_CLUBS = 0,
	CS_SPADES,
	CS_DIAMONDS,
	CS_HEARTS,
	CS_HIGHSUIT = CS_HEARTS
} CardSuit ;

typedef enum _CardColor
{
	CS_BLACK = 0,
	CS_RED
} CardColor ;


@interface Card:Object
{
	CardSuit		suit ;
	CardValue	value ;
	BOOL		faceUp ;
}

/*----------------------------------------------------------------------------
|
|	Class initialization
|
\---------------------------------------------------------------------------*/

+ initialize ;

/*----------------------------------------------------------------------------
|
|	Creating and freeing
|
\---------------------------------------------------------------------------*/

- init ;
- initSuit: (CardSuit) aSuit value: (CardValue) aValue ;
- initSuit: (CardSuit) aSuit value: (CardValue) aValue faceUp: (BOOL) anOrientation ;

/*----------------------------------------------------------------------------
|
|	Setting Card object state
|
\---------------------------------------------------------------------------*/

- setSuit: (CardSuit) aSuit ;
- setValue: (CardValue) aValue ;
- flip ;
- setFaceUp: (BOOL) aSide ;

/*----------------------------------------------------------------------------
|
|	Determining Card object state
|
\---------------------------------------------------------------------------*/

- (CardSuit) suit ;
- (CardValue) value ;
- (BOOL) isFaceUp ;
- (CardColor) cardColor ;

/*----------------------------------------------------------------------------
|
|	Drawing the card
|
\---------------------------------------------------------------------------*/

- drawCardAt: (NXPoint *) thePoint ;
- drawContentsAt: (NXPoint *) thePoint ;
- drawOutlineAt: (NXPoint *) thePoint ;

/*----------------------------------------------------------------------------
|
|	Archiving
|
\---------------------------------------------------------------------------*/

- read: (NXTypedStream *) theStream ;
- write: (NXTypedStream *) theStream ;

@end
