
/*-----------------------------------------------------------------------------------------------------------------------------------
| -----------------------------------------------------------------------------------------------------------------------------------
|
|	CardPileView : View : Responder : Object
|
|	Instances of this class provide a visual representation of a pile of cards.  CardPileView
|	uses CardPile as the underlying representation, but adds a visual aspect and user
|	interaction.  Users can click on CardPileViews and drag cards from one view to another.
|	The decisions on when this is allowed and what happens as a result are left to the
|	CardPileView's delegate.
|
| -----------------------------------------------------------------------------------------------------------------------------------
\----------------------------------------------------------------------------------------------------------------------------------*/

#import <appkit/appkit.h>

/*----------------------------------------------------------------------------
|
|	Card dimensions
|
\---------------------------------------------------------------------------*/

#define	CS_CARDWIDTH		107
#define	CS_CARDHEIGHT		168

/*----------------------------------------------------------------------------
|
|	Delegate method flags
|
\---------------------------------------------------------------------------*/

#define	CS_CLICKED			0x1
#define	CS_DRAGGED		0x2
#define	CS_CANACCEPT		0x4
#define	CS_ACCEPT			0x8
#define	CS_REMOVED		0x10
#define	CS_GETOFFSET		0x20


@interface CardPileView:View
{
	float		xOffset, yOffset ;
	id		cardPile, dragCardPile ;
	BOOL	useDragCardPile ;
	id		delegate ;
	int		delegateFlags ;
	int		tag ;
}

/*----------------------------------------------------------------------------
|
|	Class initialization
|
\---------------------------------------------------------------------------*/

+ initialize ;

/*----------------------------------------------------------------------------
|
|	Creating and freeing
|
\---------------------------------------------------------------------------*/

- initFrame: (NXRect *) frameRect  ;
- free ;

/*----------------------------------------------------------------------------
|
|	Managing related objects
|
\---------------------------------------------------------------------------*/

- setDelegate: anObject ;
- delegate ;
- cardPile ;

/*----------------------------------------------------------------------------
|
|	Displaying the CardPile
|
\---------------------------------------------------------------------------*/

- drawSelf: (NXRect *) theRect : (int) rectCount ;

/*----------------------------------------------------------------------------
|
|	Responder methods
|
\---------------------------------------------------------------------------*/

- mouseDown: (NXEvent *) theEvent ;

/*----------------------------------------------------------------------------
|
|	Drag and drop methods
|
\---------------------------------------------------------------------------*/

- (NXDragOperation) draggingSourceOperationMaskForLocal: (BOOL) flag ;
- draggedImage: (NXImage *) image beganAt: (NXPoint *) screenPoint ;
- draggedImage: (NXImage *) image endedAt: (NXPoint *) screenPoint deposited: (BOOL) flag ;
- (NXDragOperation) draggingEntered: sender ;
- (BOOL) prepareForDragOperation: sender ;
- (BOOL) performDragOperation: sender ;

/*----------------------------------------------------------------------------
|
|	Utility
|
\---------------------------------------------------------------------------*/

- findCardAt: (NXPoint *) thePoint ;
- getRect: (NXRect *) cardRect forCard: aCard ;
- drawDragCard: sender ;

@end


/*-----------------------------------------------------------------------------------------------------------------------------------
| -----------------------------------------------------------------------------------------------------------------------------------
|
|	CardPileViewDelegate
|
|	These methods may be implemented by a delegate of CardPileView
|
| -----------------------------------------------------------------------------------------------------------------------------------
\----------------------------------------------------------------------------------------------------------------------------------*/

@interface Object ( CardPileViewDelegate )

- clickedCard: aCard in: aCardPileView ;
- (BOOL) draggedPile: aCardPile from: aCardPileView ;
- (BOOL) canAcceptPile: aCardPile in: aCardPileView ;
- acceptPile: aCardPile in: aCardPileView ;
- removedPile: aCardPile from: aCardPileView ;
- getOffset: (float *) xOffset : (float *) yOffset ;

@end
